Crate batch_mode

Structs

BatchChoice
BatchErrorData
BatchErrorDetails
BatchErrorResponseBody
BatchExecutionResult
BatchFileReconciliationRecommendedCourseOfAction
BatchFileTriple
Represents the batch files associated with a specific index.
BatchInputData
BatchMessage
BatchMessageContent
BatchMetadata
BatchOnlineStatus
BatchOutputData
BatchRequestRecord
BatchResponseContent
BatchResponseRecord
BatchSuccessResponseBody
BatchTokenDetails
BatchUsage
BatchWorkspace
CamelCaseTokenWithComment
OpenAIClientHandle
ResponseRequestId

Enums

BatchDownloadError
BatchErrorFileProcessingOperation
BatchErrorProcessingError
BatchFileState
Represents the state of batch files based on the presence of input, output, and error files.
BatchFileTripleReconciliationOperation
BatchIndex
Represents the type of index found in the file names.
BatchIndexType
BatchMetadataError
BatchOutputProcessingError
BatchProcessingError
BatchReconciliationError
BatchResponseBody
BatchSuccessResponseHandlingError
BatchValidationError
BatchWorkspaceError
ContentParseError
ErrorSavingFailedBatchEntries
ErrorType
ExpectedContentType
FileMoveError
FinishReason
JsonParseError
MessageRole
OpenAIClientError
SaveLoadError
TokenParseError
UuidParseError

Traits

BatchWorkspaceInterface
FilePattern
GetDoneDirectory
GetErrorFilenameAtIndex
GetFailedItemsDir
GetFailedJsonRepairsDir
GetInputFilenameAtIndex
GetMetadataFilenameAtIndex
GetOutputFilenameAtIndex
GetTextStoragePath
GetTokenExpansionPath
LoadFromDirectory
Trait for loading objects from a directory asynchronously.
LoadFromFile
SaveToFile

Functions

check_batch_status_online
check_for_and_download_output_and_error_online
download_error_file
download_output_file
execute_reconciliation_operation
extract_json_from_possible_backticks_block
Extracts JSON from a content string by removing surrounding json\n and \n markers if present, and trims any leading or trailing whitespace from the input.
extract_token_name_field
Extracts the “token_name” field from a JSON object.
fresh_execute_batch_processing
handle_failed_json_repair
handle_finish_reason_length
handle_successful_response
load_error_file
load_input_file
load_output_file
parse_token_file
process_batch_output_and_errors
process_error_data
process_error_file
process_output_data
process_output_file
recalculate_recommended_actions
reconcile_unprocessed_batch_triple
save_failed_entries
write_to_file
Writes serialized JSON content to a file asynchronously.

Type Aliases

TokenQuad